import lombok.AccessLevel;
class LoggerCommonsAccessPublic {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	public static final org.apache.commons.logging.Log log = org.apache.commons.logging.LogFactory.getLog(LoggerCommonsAccessPublic.class);

}
class LoggerCommonsAccessModule {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	static final org.apache.commons.logging.Log log = org.apache.commons.logging.LogFactory.getLog(LoggerCommonsAccessModule.class);

}
class LoggerCommonsAccessProtected {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	protected static final org.apache.commons.logging.Log log = org.apache.commons.logging.LogFactory.getLog(LoggerCommonsAccessProtected.class);

}
class LoggerCommonsAccessPackage {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	static final org.apache.commons.logging.Log log = org.apache.commons.logging.LogFactory.getLog(LoggerCommonsAccessPackage.class);

}
class LoggerCommonsAccessPrivate {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	private static final org.apache.commons.logging.Log log = org.apache.commons.logging.LogFactory.getLog(LoggerCommonsAccessPrivate.class);

}
class LoggerCommonsAccessNone {
}
