import lombok.AccessLevel;
class LoggerXslf4jAccessPublic {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	public static final org.slf4j.ext.XLogger log = org.slf4j.ext.XLoggerFactory.getXLogger(LoggerXslf4jAccessPublic.class);

}
class LoggerXslf4jAccessModule {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	static final org.slf4j.ext.XLogger log = org.slf4j.ext.XLoggerFactory.getXLogger(LoggerXslf4jAccessModule.class);

}
class LoggerXslf4jAccessProtected {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	protected static final org.slf4j.ext.XLogger log = org.slf4j.ext.XLoggerFactory.getXLogger(LoggerXslf4jAccessProtected.class);

}
class LoggerXslf4jAccessPackage {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	static final org.slf4j.ext.XLogger log = org.slf4j.ext.XLoggerFactory.getXLogger(LoggerXslf4jAccessPackage.class);

}
class LoggerXslf4jAccessPrivate {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	private static final org.slf4j.ext.XLogger log = org.slf4j.ext.XLoggerFactory.getXLogger(LoggerXslf4jAccessPrivate.class);

}
class LoggerXslf4jAccessNone {
}
