import lombok.AccessLevel;
import lombok.extern.java.Log;
@Log(access = AccessLevel.PUBLIC) class LoggerJulAccessPublic {
  public static final @java.lang.SuppressWarnings("all") @lombok.Generated java.util.logging.Logger log = java.util.logging.Logger.getLogger(LoggerJulAccessPublic.class.getName());
  <clinit>() {
  }

  LoggerJulAccessPublic() {
    super();
  }
}
@Log(access = AccessLevel.MODULE) class LoggerJulAccessModule {
  static final @java.lang.SuppressWarnings("all") @lombok.Generated java.util.logging.Logger log = java.util.logging.Logger.getLogger(LoggerJulAccessModule.class.getName());
  <clinit>() {
  }

  LoggerJulAccessModule() {
    super();
  }
}
@Log(access = AccessLevel.PROTECTED) class LoggerJulAccessProtected {
  protected static final @java.lang.SuppressWarnings("all") @lombok.Generated java.util.logging.Logger log = java.util.logging.Logger.getLogger(LoggerJulAccessProtected.class.getName());
  <clinit>() {
  }

  LoggerJulAccessProtected() {
    super();
  }
}
@Log(access = AccessLevel.PACKAGE) class LoggerJulAccessPackage {
  static final @java.lang.SuppressWarnings("all") @lombok.Generated java.util.logging.Logger log = java.util.logging.Logger.getLogger(LoggerJulAccessPackage.class.getName());
  <clinit>() {
  }

  LoggerJulAccessPackage() {
    super();
  }
}
@Log(access = AccessLevel.PRIVATE) class LoggerJulAccessPrivate {
  private static final @java.lang.SuppressWarnings("all") @lombok.Generated java.util.logging.Logger log = java.util.logging.Logger.getLogger(LoggerJulAccessPrivate.class.getName());
  <clinit>() {
  }

  LoggerJulAccessPrivate() {
    super();
  }
}
@Log(access = AccessLevel.NONE) class LoggerJulAccessNone {
  LoggerJulAccessNone() {
    super();
  }
}
