import lombok.AccessLevel;
class LoggerLog4j2AccessPublic {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	public static final org.apache.logging.log4j.Logger log = org.apache.logging.log4j.LogManager.getLogger(LoggerLog4j2AccessPublic.class);

}
class LoggerLog4j2AccessModule {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	static final org.apache.logging.log4j.Logger log = org.apache.logging.log4j.LogManager.getLogger(LoggerLog4j2AccessModule.class);

}
class LoggerLog4j2AccessProtected {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	protected static final org.apache.logging.log4j.Logger log = org.apache.logging.log4j.LogManager.getLogger(LoggerLog4j2AccessProtected.class);

}
class LoggerLog4j2AccessPackage {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	static final org.apache.logging.log4j.Logger log = org.apache.logging.log4j.LogManager.getLogger(LoggerLog4j2AccessPackage.class);

}
class LoggerLog4j2AccessPrivate {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	private static final org.apache.logging.log4j.Logger log = org.apache.logging.log4j.LogManager.getLogger(LoggerLog4j2AccessPrivate.class);

}
class LoggerLog4j2AccessNone {
}
