import lombok.AccessLevel;
class LoggerJBossLogAccessPublic {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	public static final org.jboss.logging.Logger log = org.jboss.logging.Logger.getLogger(LoggerJBossLogAccessPublic.class);

}
class LoggerJBossLogAccessModule {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	static final org.jboss.logging.Logger log = org.jboss.logging.Logger.getLogger(LoggerJBossLogAccessModule.class);

}
class LoggerJBossLogAccessProtected {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	protected static final org.jboss.logging.Logger log = org.jboss.logging.Logger.getLogger(LoggerJBossLogAccessProtected.class);

}
class LoggerJBossLogAccessPackage {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	static final org.jboss.logging.Logger log = org.jboss.logging.Logger.getLogger(LoggerJBossLogAccessPackage.class);

}
class LoggerJBossLogAccessPrivate {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	private static final org.jboss.logging.Logger log = org.jboss.logging.Logger.getLogger(LoggerJBossLogAccessPrivate.class);

}
class LoggerJBossLogAccessNone {
}
