import lombok.AccessLevel;
import lombok.extern.apachecommons.CommonsLog;
@CommonsLog(access = AccessLevel.PUBLIC) class LoggerCommonsAccessPublic {
  public static final @java.lang.SuppressWarnings("all") @lombok.Generated org.apache.commons.logging.Log log = org.apache.commons.logging.LogFactory.getLog(LoggerCommonsAccessPublic.class);
  <clinit>() {
  }

  LoggerCommonsAccessPublic() {
    super();
  }
}
@CommonsLog(access = AccessLevel.MODULE) class LoggerCommonsAccessModule {
  static final @java.lang.SuppressWarnings("all") @lombok.Generated org.apache.commons.logging.Log log = org.apache.commons.logging.LogFactory.getLog(LoggerCommonsAccessModule.class);
  <clinit>() {
  }

  LoggerCommonsAccessModule() {
    super();
  }
}
@CommonsLog(access = AccessLevel.PROTECTED) class LoggerCommonsAccessProtected {
  protected static final @java.lang.SuppressWarnings("all") @lombok.Generated org.apache.commons.logging.Log log = org.apache.commons.logging.LogFactory.getLog(LoggerCommonsAccessProtected.class);
  <clinit>() {
  }

  LoggerCommonsAccessProtected() {
    super();
  }
}
@CommonsLog(access = AccessLevel.PACKAGE) class LoggerCommonsAccessPackage {
  static final @java.lang.SuppressWarnings("all") @lombok.Generated org.apache.commons.logging.Log log = org.apache.commons.logging.LogFactory.getLog(LoggerCommonsAccessPackage.class);
  <clinit>() {
  }

  LoggerCommonsAccessPackage() {
    super();
  }
}
@CommonsLog(access = AccessLevel.PRIVATE) class LoggerCommonsAccessPrivate {
  private static final @java.lang.SuppressWarnings("all") @lombok.Generated org.apache.commons.logging.Log log = org.apache.commons.logging.LogFactory.getLog(LoggerCommonsAccessPrivate.class);
  <clinit>() {
  }

  LoggerCommonsAccessPrivate() {
    super();
  }
}
@CommonsLog(access = AccessLevel.NONE) class LoggerCommonsAccessNone {
  LoggerCommonsAccessNone() {
    super();
  }
}
