import lombok.AccessLevel;
class LoggerSlf4jAccessPublic {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	public static final org.slf4j.Logger log = org.slf4j.LoggerFactory.getLogger(LoggerSlf4jAccessPublic.class);

}
class LoggerSlf4jAccessModule {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	static final org.slf4j.Logger log = org.slf4j.LoggerFactory.getLogger(LoggerSlf4jAccessModule.class);

}
class LoggerSlf4jAccessProtected {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	protected static final org.slf4j.Logger log = org.slf4j.LoggerFactory.getLogger(LoggerSlf4jAccessProtected.class);

}
class LoggerSlf4jAccessPackage {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	static final org.slf4j.Logger log = org.slf4j.LoggerFactory.getLogger(LoggerSlf4jAccessPackage.class);

}
class LoggerSlf4jAccessPrivate {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	private static final org.slf4j.Logger log = org.slf4j.LoggerFactory.getLogger(LoggerSlf4jAccessPrivate.class);

}
class LoggerSlf4jAccessNone {
}
