import lombok.AccessLevel;
class LoggerFloggerAccessPublic {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	public static final com.google.common.flogger.FluentLogger log = com.google.common.flogger.FluentLogger.forEnclosingClass();

}
class LoggerFloggerAccessModule {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	static final com.google.common.flogger.FluentLogger log = com.google.common.flogger.FluentLogger.forEnclosingClass();

}
class LoggerFloggerAccessProtected {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	protected static final com.google.common.flogger.FluentLogger log = com.google.common.flogger.FluentLogger.forEnclosingClass();

}
class LoggerFloggerAccessPackage {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	static final com.google.common.flogger.FluentLogger log = com.google.common.flogger.FluentLogger.forEnclosingClass();

}
class LoggerFloggerAccessPrivate {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	private static final com.google.common.flogger.FluentLogger log = com.google.common.flogger.FluentLogger.forEnclosingClass();

}
class LoggerFloggerAccessNone {
}
