import lombok.AccessLevel;
class LoggerLog4jAccessPublic {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	public static final org.apache.log4j.Logger log = org.apache.log4j.Logger.getLogger(LoggerLog4jAccessPublic.class);

}
class LoggerLog4jAccessModule {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	static final org.apache.log4j.Logger log = org.apache.log4j.Logger.getLogger(LoggerLog4jAccessModule.class);

}
class LoggerLog4jAccessProtected {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	protected static final org.apache.log4j.Logger log = org.apache.log4j.Logger.getLogger(LoggerLog4jAccessProtected.class);

}
class LoggerLog4jAccessPackage {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	static final org.apache.log4j.Logger log = org.apache.log4j.Logger.getLogger(LoggerLog4jAccessPackage.class);

}
class LoggerLog4jAccessPrivate {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	private static final org.apache.log4j.Logger log = org.apache.log4j.Logger.getLogger(LoggerLog4jAccessPrivate.class);

}
class LoggerLog4jAccessNone {
}
