import lombok.AccessLevel;
import lombok.extern.log4j.Log4j2;
@Log4j2(access = AccessLevel.PUBLIC) class LoggerLog4j2AccessPublic {
  public static final @java.lang.SuppressWarnings("all") @lombok.Generated org.apache.logging.log4j.Logger log = org.apache.logging.log4j.LogManager.getLogger(LoggerLog4j2AccessPublic.class);
  <clinit>() {
  }

  LoggerLog4j2AccessPublic() {
    super();
  }
}
@Log4j2(access = AccessLevel.MODULE) class LoggerLog4j2AccessModule {
  static final @java.lang.SuppressWarnings("all") @lombok.Generated org.apache.logging.log4j.Logger log = org.apache.logging.log4j.LogManager.getLogger(LoggerLog4j2AccessModule.class);
  <clinit>() {
  }

  LoggerLog4j2AccessModule() {
    super();
  }
}
@Log4j2(access = AccessLevel.PROTECTED) class LoggerLog4j2AccessProtected {
  protected static final @java.lang.SuppressWarnings("all") @lombok.Generated org.apache.logging.log4j.Logger log = org.apache.logging.log4j.LogManager.getLogger(LoggerLog4j2AccessProtected.class);
  <clinit>() {
  }

  LoggerLog4j2AccessProtected() {
    super();
  }
}
@Log4j2(access = AccessLevel.PACKAGE) class LoggerLog4j2AccessPackage {
  static final @java.lang.SuppressWarnings("all") @lombok.Generated org.apache.logging.log4j.Logger log = org.apache.logging.log4j.LogManager.getLogger(LoggerLog4j2AccessPackage.class);
  <clinit>() {
  }

  LoggerLog4j2AccessPackage() {
    super();
  }
}
@Log4j2(access = AccessLevel.PRIVATE) class LoggerLog4j2AccessPrivate {
  private static final @java.lang.SuppressWarnings("all") @lombok.Generated org.apache.logging.log4j.Logger log = org.apache.logging.log4j.LogManager.getLogger(LoggerLog4j2AccessPrivate.class);
  <clinit>() {
  }

  LoggerLog4j2AccessPrivate() {
    super();
  }
}
@Log4j2(access = AccessLevel.NONE) class LoggerLog4j2AccessNone {
  LoggerLog4j2AccessNone() {
    super();
  }
}
