import lombok.AccessLevel;
class LoggerJulAccessPublic {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	public static final java.util.logging.Logger log = java.util.logging.Logger.getLogger(LoggerJulAccessPublic.class.getName());

}
class LoggerJulAccessModule {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	static final java.util.logging.Logger log = java.util.logging.Logger.getLogger(LoggerJulAccessModule.class.getName());

}
class LoggerJulAccessProtected {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	protected static final java.util.logging.Logger log = java.util.logging.Logger.getLogger(LoggerJulAccessProtected.class.getName());

}
class LoggerJulAccessPackage {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	static final java.util.logging.Logger log = java.util.logging.Logger.getLogger(LoggerJulAccessPackage.class.getName());

}
class LoggerJulAccessPrivate {
	@java.lang.SuppressWarnings("all")
	@lombok.Generated
	private static final java.util.logging.Logger log = java.util.logging.Logger.getLogger(LoggerJulAccessPrivate.class.getName());

}
class LoggerJulAccessNone {
}
